@@ -16,6 +16,7 @@ import sys
 if not os.getenv('DISPLAY', ''):
     os.putenv('DISPLAY', ':0.0')
 
+import pwd
 import pathlib
 import re
 import json
@@ -651,6 +652,26 @@ class MainWindow(QMainWindow):
         self.act_show_hidden.setChecked(self.showHiddenFiles)
         self.act_show_hidden.toggled.connect(self.btnShowHiddenFilesToggled)
 
+        # Workaround: Not easy to open URLs in webbrowser with BIT in root
+        # mode. For v1.5.6. we just disable that and give a hint via tooltip.
+        # Will be improved in versions ater that.
+        if pwd.getpwuid(os.getuid()).pw_name == 'root':  # BIT root-mode
+            tooltip = 'Not available in root mode.'
+            the_keys = [
+                'act_help_user_manual',
+                'act_help_website',
+                'act_help_changelog',
+                'act_help_faq',
+                'act_help_question',
+                'act_help_bugreport',
+            ]
+
+            for act_key in the_keys:
+                act = getattr(self, act_key)
+                act.setEnabled(False)
+                act.setToolTip(tooltip)
+
+
     def _create_shortcuts_without_actions(self):
         """Create shortcuts that are not related to a visual element in the
         GUI and don't have an QAction instance because of that.
@@ -1456,6 +1477,12 @@ class MainWindow(QMainWindow):
             return '<a href="https://bugs.launchpad.net/backintime/+bug/%(id)s">%(txt)s</a>' % {'txt': m.group(0), 'id': m.group(1)}
 
         changelog_path = pathlib.Path(tools.docPath()) / 'CHANGES'
+
+        if not changelog_path.exists():
+            url = 'https://github.com/bit-team/backintime/blob/dev/CHANGES'
+            QDesktopServices.openUrl(QUrl(url))
+            return
+
         msg = changelog_path.read_text('utf-8')
         msg = re.sub(r'https?://[^) \n]*', aHref, msg)
         msg = re.sub(r'(?:LP:|bug) ?#?(\d+)', aHref_lp, msg)
